==> apache-devlake-0.16.0-incubating-src.tar.gz: apache-devlake-0.16.0-incubating-src/config-ui/src/pages/connection/form/index.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

import React, { useMemo } from 'react';
import { useParams } from 'react-router-dom';

import { PageHeader } from '@/components';
import type { PluginConfigType } from '@/plugins';
import { PluginConfig, ConnectionForm } from '@/plugins';

export const ConnectionFormPage = () => {
  const { plugin, cid } = useParams<{ plugin: string; cid?: string }>();

  const { name } = useMemo(() => PluginConfig.find((p) => p.plugin === plugin) as PluginConfigType, [plugin]);

  return (
    <PageHeader
      breadcrumbs={[
        { name: 'Connections', path: '/connections' },
        { name, path: `/connections/${plugin}` },
        {
          name: cid ? cid : 'Create a New Connection',
          path: `/connections/${plugin}/${cid ? cid : 'create'}`,
        },
      ]}
    >
      <ConnectionForm plugin={plugin} connectionId={cid} />
    </PageHeader>
  );
};

==> apache-devlake-0.17.0-incubating-src.tar.gz: apache-devlake-0.17.0-incubating-src/config-ui/src/pages/connection/form/index.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

import React, { useMemo } from 'react';
import { useParams } from 'react-router-dom';

import { PageHeader } from '@/components';
import { ConnectionForm, getPluginConfig } from '@/plugins';

export const ConnectionFormPage = () => {
  const { plugin, cid } = useParams<{ plugin: string; cid?: string }>();

  const { name } = useMemo(() => getPluginConfig(plugin), [plugin]);

  return (
    <PageHeader
      breadcrumbs={[
        { name: 'Connections', path: '/connections' },
        { name, path: `/connections/${plugin}` },
        {
          name: cid ? cid : 'Create a New Connection',
          path: `/connections/${plugin}/${cid ? cid : 'create'}`,
        },
      ]}
    >
      <ConnectionForm plugin={plugin} connectionId={cid} />
    </PageHeader>
  );
};
